# Generated by Django 4.2.21 on 2025-08-30 04:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0012_remove_pushconfig_apns_key_file_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='pushconfig',
            name='test_mode',
            field=models.BooleanField(db_index=True, default=False, help_text='Enable test mode - fake notifications for development'),
        ),
        migrations.AlterField(
            model_name='pushconfig',
            name='apns_enabled',
            field=models.BooleanField(default=False, help_text='APNS for iOS-specific needs. FCM is preferred.'),
        ),
        migrations.AlterField(
            model_name='pushconfig',
            name='fcm_enabled',
            field=models.BooleanField(default=True, help_text='FCM handles both iOS and Android notifications'),
        ),
    ]
