# Generated by Django 5.2.7 on 2026-03-14 06:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='shortlink',
            name='is_protected',
            field=models.BooleanField(default=False, help_text='Protected links are not deleted by the cleanup job'),
        ),
    ]
