# Generated by Django 4.2.21 on 2025-06-04 19:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0002_user_is_email_verified_user_is_phone_verified'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='mojo_secrets',
            field=models.TextField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='mojo_secrets',
            field=models.TextField(blank=True, default=None, null=True),
        ),
    ]
