# Generated by Django 4.2.21 on 2025-06-07 14:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0005_incidenthistory'),
    ]

    operations = [
        migrations.AlterField(
            model_name='incident',
            name='state',
            field=models.CharField(db_index=True, default=0, max_length=24),
        ),
    ]
