# Generated by Django 5.2.7 on 2026-03-15 22:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0032_notification'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='dob',
            field=models.DateField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='is_dob_verified',
            field=models.BooleanField(default=False),
        ),
    ]
