# Generated by Django 4.2.21 on 2025-08-29 03:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('fileman', '0011_alter_filerendition_original_file'),
        ('account', '0009_geolocatedip_subnet'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='avatar',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='fileman.file'),
        ),
    ]
