# Generated by Django 4.2.21 on 2025-08-29 00:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0008_userdevicelocation'),
    ]

    operations = [
        migrations.AddField(
            model_name='geolocatedip',
            name='subnet',
            field=models.CharField(db_index=True, default=None, max_length=16, null=True),
        ),
    ]
