# Generated by Django 4.2.21 on 2025-06-07 20:02

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('fileman', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='filemanager',
            name='parent',
            field=models.ForeignKey(blank=True, help_text='Used if this file manager is a child of another file manager, and inherits settings from its parent', null=True, on_delete=django.db.models.deletion.CASCADE, to='fileman.filemanager'),
        ),
        migrations.AlterField(
            model_name='filemanager',
            name='max_file_size',
            field=models.BigIntegerField(default=1048576000, help_text='Maximum file size in bytes (0 for unlimited)'),
        ),
    ]
