# Generated by Django 5.2.6 on 2025-10-15 22:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0016_geolocatedip_asn_geolocatedip_asn_org_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='geolocatedip',
            name='last_seen',
            field=models.DateTimeField(auto_now=True, db_index=True, help_text='Last time this IP was encountered in the system'),
        ),
    ]
