"""
DocIt REST Handlers

Import all REST endpoint handlers to register them with Django-MOJO
"""

from .book import *
from .page import *
from .page_revision import *
from .asset import *
from .render import *
