# Generated by Django 4.2.25 on 2025-10-23 00:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0021_remove_pushconfig_fcm_sender_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='geolocatedip',
            name='is_mobile',
            field=models.BooleanField(default=False, db_index=True, help_text='Is this IP from a mobile/cellular carrier?'),
        ),
        migrations.AddField(
            model_name='geolocatedip',
            name='mobile_carrier',
            field=models.CharField(blank=True, db_index=True, help_text='Mobile carrier name (Verizon, AT&T, T-Mobile, etc.)', max_length=100, null=True),
        ),
        migrations.AddIndex(
            model_name='geolocatedip',
            index=models.Index(fields=['is_mobile', 'mobile_carrier'], name='account_geo_is_mobi_8a7c2e_idx'),
        ),
    ]
