# Generated by Django 5.2.12 on 2026-04-01 11:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0023_rename_by_incidenthistory_user'),
    ]

    operations = [
        migrations.AddField(
            model_name='ruleset',
            name='retrigger_every',
            field=models.IntegerField(blank=True, help_text='Re-fire handler every N additional events after the initial trigger. Null = fire once only.', null=True),
        ),
        migrations.AddField(
            model_name='ruleset',
            name='trigger_count',
            field=models.IntegerField(blank=True, help_text='Fire handler when incident reaches this many events. Null = fire immediately on first event.', null=True),
        ),
        migrations.AddField(
            model_name='ruleset',
            name='trigger_window',
            field=models.IntegerField(blank=True, help_text='Only count events within this many minutes for the trigger threshold. Null = count all events on the incident.', null=True),
        ),
    ]
