# Generated by Django 5.2.12 on 2026-03-29 03:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aws', '0008_alter_emaildomain_region'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emaildomain',
            name='region',
            field=models.CharField(blank=True, default='', help_text='AWS region for SES operations. Leave blank to use AWS_REGION setting.', max_length=64),
        ),
    ]
