# Generated by Django 4.2.21 on 2025-06-08 13:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('fileman', '0005_alter_file_upload_token'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='download_url',
            field=models.TextField(blank=True, default=None, help_text='Persistent URL for downloading the file, (if allowed)', null=True),
        ),
        migrations.AddField(
            model_name='filemanager',
            name='forever_urls',
            field=models.BooleanField(default=False, help_text='Allow URLs to be permanent and not expire'),
        ),
    ]
