# Generated by Django 4.2.23 on 2025-09-05 22:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0009_incident_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='event',
            name='country_code',
            field=models.CharField(db_index=True, default=None, max_length=2, null=True),
        ),
    ]
