# Generated by Django 5.2.12 on 2026-04-02 20:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('assistant', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='message',
            name='blocks',
            field=models.JSONField(blank=True, default=None, null=True),
        ),
    ]
