# Generated by Django 4.2.21 on 2025-08-29 18:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0006_alter_incident_state'),
    ]

    operations = [
        migrations.AddField(
            model_name='event',
            name='uid',
            field=models.IntegerField(db_index=True, default=None, null=True),
        ),
    ]
