# Generated by Django 5.2.6 on 2026-01-09 16:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('logit', '0005_alter_log_created_alter_log_ip_alter_log_kind_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False),
        ),
    ]
