# Generated by Django 5.2.12 on 2026-03-29 03:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0022_ipset'),
    ]

    operations = [
        migrations.RenameField(
            model_name='incidenthistory',
            old_name='by',
            new_name='user',
        ),
    ]
