# Generated by Django 4.2.23 on 2025-09-02 22:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0013_pushconfig_test_mode_alter_pushconfig_apns_enabled_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='notificationdelivery',
            name='data_payload',
            field=models.JSONField(blank=True, default=dict, help_text='Custom data payload sent with notification'),
        ),
        migrations.AddField(
            model_name='notificationtemplate',
            name='data_template',
            field=models.JSONField(blank=True, default=dict, help_text='Template data payload with variable support'),
        ),
        migrations.AlterField(
            model_name='notificationdelivery',
            name='body',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='notificationdelivery',
            name='title',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='notificationtemplate',
            name='body_template',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='notificationtemplate',
            name='title_template',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='notificationtemplate',
            name='variables',
            field=models.JSONField(blank=True, default=dict, help_text='Expected template variables and descriptions for title, body, action_url, and data_template'),
        ),
    ]
