# Generated by Django 4.2.25 on 2025-12-04 02:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0018_ruleset_bundle_by_rule_set'),
    ]

    operations = [
        migrations.AddField(
            model_name='event',
            name='scope',
            field=models.CharField(db_index=True, default='global', max_length=64),
        ),
        migrations.AddField(
            model_name='incident',
            name='scope',
            field=models.CharField(db_index=True, default='global', max_length=64),
        ),
    ]
