# Generated by Django 5.2.6 on 2025-12-09 15:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0019_event_scope_incident_scope'),
    ]

    operations = [
        migrations.AlterField(
            model_name='rule',
            name='value',
            field=models.TextField(default=''),
        ),
    ]
