# Generated by Django 5.2.6 on 2025-09-15 23:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('logit', '0004_alter_log_level'),
    ]

    operations = [
        migrations.AlterField(
            model_name='log',
            name='created',
            field=models.DateTimeField(auto_now_add=True),
        ),
        migrations.AlterField(
            model_name='log',
            name='ip',
            field=models.CharField(default=None, max_length=32, null=True),
        ),
        migrations.AlterField(
            model_name='log',
            name='kind',
            field=models.CharField(default=None, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='log',
            name='level',
            field=models.CharField(default='info', max_length=12),
        ),
        migrations.AlterField(
            model_name='log',
            name='model_id',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='log',
            name='model_name',
            field=models.TextField(default=None, null=True),
        ),
        migrations.AlterField(
            model_name='log',
            name='path',
            field=models.TextField(default=None, null=True),
        ),
        migrations.AlterField(
            model_name='log',
            name='uid',
            field=models.IntegerField(default=0),
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['created'], name='logit_log_created_199229_idx'),
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['level'], name='logit_log_level_5a47f5_idx'),
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['kind'], name='logit_log_kind_4f9860_idx'),
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['path'], name='logit_log_path_e05d86_idx'),
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['ip'], name='logit_log_ip_c748d1_idx'),
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['uid'], name='logit_log_uid_629b83_idx'),
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['model_name', 'model_id'], name='logit_log_model_n_871613_idx'),
        ),
        migrations.AddIndex(
            model_name='log',
            index=models.Index(fields=['created', 'kind'], name='logit_log_created_963e15_idx'),
        ),
    ]
