# Generated by Django 5.2.6 on 2025-09-26 22:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0014_ticket_category_alter_ticket_description'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='ticket',
            options={'ordering': ['-modified']},
        ),
    ]
