# Generated by Django 4.2.21 on 2025-08-26 16:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0004_user_avatar'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='last_activity',
            field=models.DateTimeField(db_index=True, default=None, null=True),
        ),
    ]
