# Generated by Django 4.2.21 on 2025-06-04 17:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0003_alter_event_model_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='incident',
            name='model_id',
            field=models.IntegerField(db_index=True, default=None, null=True),
        ),
    ]
