# Generated by Django 4.2.21 on 2025-08-28 16:24

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0006_add_device_tracking_models'),
    ]

    operations = [
        migrations.DeleteModel(
            name='UserDeviceLocation',
        ),
    ]
