# Generated by Django 5.2.7 on 2026-03-12 18:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0030_alter_user_phone_number'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='requires_mfa',
            field=models.BooleanField(default=False),
        ),
    ]
