# Generated by Django 5.2.6 on 2025-09-24 16:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0013_rename_author_ticketnote_user'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='category',
            field=models.CharField(db_index=True, default='ticket', max_length=80),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='description',
            field=models.TextField(blank=True, default=None, null=True),
        ),
    ]
