# Generated by Django 5.2.7 on 2026-02-24 17:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0026_apikey'),
    ]

    operations = [
        migrations.AddField(
            model_name='apikey',
            name='metadata',
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
