# Generated by Django 4.2.21 on 2025-05-29 23:29

from django.db import migrations, models
import mojo.models.rest


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, db_index=True)),
                ('kind', models.CharField(db_index=True, default=None, max_length=200, null=True)),
                ('method', models.CharField(default=None, max_length=200, null=True)),
                ('path', models.TextField(db_index=True, default=None, null=True)),
                ('ip', models.CharField(db_index=True, default=None, max_length=32, null=True)),
                ('uid', models.IntegerField(db_index=True, default=0)),
                ('user_agent', models.TextField(default=None)),
                ('log', models.TextField(default=None, null=True)),
                ('model_name', models.TextField(db_index=True, default=None, null=True)),
                ('model_id', models.IntegerField(db_index=True, default=0)),
            ],
            bases=(models.Model, mojo.models.rest.MojoModel),
        ),
    ]
