# Generated by Django 5.2.6 on 2025-11-24 00:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0017_alter_ruleset_bundle_by_alter_ruleset_bundle_minutes_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='ruleset',
            name='bundle_by_rule_set',
            field=models.BooleanField(default=True, help_text='Bundle by rule set'),
        ),
    ]
