# Generated by Django 4.2.21 on 2025-08-31 23:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aws', '0002_emaildomain_can_recv_emaildomain_can_send_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='mailbox',
            name='is_domain_default',
            field=models.BooleanField(db_index=True, default=False, help_text='Default mailbox for this domain (one per domain)'),
        ),
        migrations.AddField(
            model_name='mailbox',
            name='is_system_default',
            field=models.BooleanField(db_index=True, default=False, help_text='System-wide default mailbox (only one allowed)'),
        ),
        migrations.AddIndex(
            model_name='mailbox',
            index=models.Index(fields=['is_system_default'], name='aws_mailbox_is_syst_9911c7_idx'),
        ),
        migrations.AddIndex(
            model_name='mailbox',
            index=models.Index(fields=['is_domain_default', 'domain'], name='aws_mailbox_is_doma_189efb_idx'),
        ),
    ]
