# Generated by Django 4.2.21 on 2025-08-30 21:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0013_pushconfig_test_mode_alter_pushconfig_apns_enabled_and_more'),
        ('docit', '0002_alter_book_modified_by_alter_page_modified_by'),
    ]

    operations = [
        migrations.AlterField(
            model_name='book',
            name='group',
            field=models.ForeignKey(blank=True, default=None, help_text='Owning group for this book', null=True, on_delete=django.db.models.deletion.CASCADE, to='account.group'),
        ),
    ]
