# Generated by Django 4.2.21 on 2025-06-08 05:14

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('fileman', '0003_remove_file_fileman_fil_upload__c4bc35_idx_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='file',
            name='original_filename',
        ),
        migrations.RemoveField(
            model_name='file',
            name='uploaded_by',
        ),
        migrations.AddField(
            model_name='file',
            name='storage_filename',
            field=models.CharField(blank=True, default=None, help_text='Storage filename', max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='file',
            name='user',
            field=models.ForeignKey(blank=True, default=None, help_text='User who uploaded this file', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='files', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='file',
            name='filename',
            field=models.CharField(db_index=True, help_text='User-provided filename', max_length=255),
        ),
    ]
