# Generated by Django 5.2.12 on 2026-03-27 17:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0036_bouncerdevice_userdevice_muid_botsignature_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='geolocatedip',
            name='block_count',
            field=models.IntegerField(default=0, help_text='Number of times this IP has been blocked'),
        ),
        migrations.AddField(
            model_name='geolocatedip',
            name='blocked_until',
            field=models.DateTimeField(blank=True, db_index=True, help_text='When the block expires (null = permanent)', null=True),
        ),
        migrations.AddField(
            model_name='geolocatedip',
            name='is_whitelisted',
            field=models.BooleanField(db_index=True, default=False, help_text='Whitelisted IPs are never blocked'),
        ),
        migrations.AddField(
            model_name='geolocatedip',
            name='whitelisted_reason',
            field=models.CharField(blank=True, help_text='Why this IP is whitelisted', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='geolocatedip',
            name='blocked_reason',
            field=models.CharField(blank=True, help_text='Why this IP was blocked', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='geolocatedip',
            name='is_blocked',
            field=models.BooleanField(db_index=True, default=False, help_text='Is this IP currently blocked?'),
        ),
        migrations.AddIndex(
            model_name='geolocatedip',
            index=models.Index(fields=['is_blocked', 'blocked_until'], name='account_geo_is_bloc_cebc9f_idx'),
        ),
        migrations.AddIndex(
            model_name='geolocatedip',
            index=models.Index(fields=['is_whitelisted'], name='account_geo_is_whit_e07919_idx'),
        ),
    ]
