# Generated by Django 5.2.6 on 2025-10-21 17:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0016_ticketnote_group'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ruleset',
            name='bundle_by',
            field=models.IntegerField(choices=[(0, "Don't bundle - each event creates new incident"), (1, 'Bundle by hostname'), (2, 'Bundle by model type'), (3, 'Bundle by specific model instance'), (4, 'Bundle by source IP'), (5, 'Bundle by hostname + model type'), (6, 'Bundle by hostname + specific model'), (7, 'Bundle by IP + model type'), (8, 'Bundle by IP + specific model'), (9, 'Bundle by IP + hostname')], default=3, help_text='How to group events into incidents'),
        ),
        migrations.AlterField(
            model_name='ruleset',
            name='bundle_minutes',
            field=models.IntegerField(blank=True, default=0, help_text='Time window in minutes for bundling events (0=disabled/no bundling, >0=time window in minutes)', null=True),
        ),
        migrations.AlterField(
            model_name='ruleset',
            name='match_by',
            field=models.IntegerField(choices=[(0, 'All rules must match'), (1, 'Any rule can match')], default=0, help_text='Rule matching mode'),
        ),
    ]
