# Generated by Django 5.2.6 on 2025-10-05 14:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0014_notificationdelivery_data_payload_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='groupmember',
            name='last_activity',
            field=models.DateTimeField(db_index=True, default=None, null=True),
        ),
    ]
