# Generated by Django 4.2.23 on 2025-09-06 00:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('incident', '0011_incident_country_code'),
    ]

    operations = [
        migrations.AlterField(
            model_name='incident',
            name='status',
            field=models.CharField(db_index=True, default='new', max_length=50),
        ),
    ]
