# Generated by Django 5.2.7 on 2025-10-25 03:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('phonehub', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='phonenumber',
            name='region',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='phonenumber',
            name='state',
            field=models.CharField(blank=True, db_index=True, max_length=3, null=True),
        ),
        migrations.AlterField(
            model_name='phonenumber',
            name='country_code',
            field=models.CharField(blank=True, db_index=True, max_length=5, null=True),
        ),
    ]
